// SPDX-FileCopyrightText: 2024 Petros Koutsolampros
//
// SPDX-License-Identifier: GPL-3.0-only

#pragma once

#include "salalib/pointmap.h"

#include <Rcpp.h>

std::vector<std::string> getPointMapAttributeNames(PointMap* pointMap);
